@@ -1,13 +1,14 @@
 package Mojo::Weixin::Group::Member;
 use Mojo::Weixin::Base 'Mojo::Weixin::Model::Base';
 
-has name => '昵称未知';
+has name => '';
 has [qw(
     account
     province
     city
     sex
     id
+    uid
     signature
     display
     markname
@@ -18,7 +19,10 @@ has [qw(
 sub new {
     my $self = shift;
     $self = $self->Mojo::Weixin::Base::new(@_);
-    $self->client->emoji_convert(\$self->{name},$self->client->emoji_to_text);
+    $self->client->emoji_convert(\$self->{markname},$self->client->emoji_to_text);
+    $self->client->emoji_convert(\$self->{display},$self->client->emoji_to_text);
+    #$self->client->emoji_convert(\$self->{name},$self->client->emoji_to_text);
+    $self->uid("") if not $self->uid;
     $self;
 }
 
@@ -28,14 +32,15 @@ sub get_avatar{
 }
 sub displayname{
     my $self = shift;
-    return $self->display || $self->markname || $self->name;
+    return $self->display || $self->markname || $self->name || '昵称未知';
 }
 sub update{
     my $self = shift;
     my $hash = shift;
     for(grep {substr($_,0,1) ne "_"} keys %$hash){
         if(exists $hash->{$_}){
-            $self->client->emoji_convert(\$hash->{$_},$self->client->emoji_to_text) if $_ eq "name";
+            $self->client->emoji_convert(\$hash->{$_},$self->client->emoji_to_text) if $_ eq "markname";
+            $self->client->emoji_convert(\$hash->{$_},$self->client->emoji_to_text) if $_ eq "display";
             if(defined $hash->{$_} and defined $self->{$_}){
                 if($hash->{$_} ne $self->{$_}){
                     my $old_property = $self->{$_};
@@ -63,4 +68,8 @@ sub make_friend{
     my $self = shift;
     $self->client->make_friend($self,@_);
 }
+sub set_markname {
+    my $self = shift;
+    $self->client->set_markname($self,@_);
+}
 1;
